@@ -1,17 +1,15 @@
 package DBIx::dbMan::Extension::Connections;
 
 use strict;
-use vars qw/$VERSION @ISA/;
-use DBIx::dbMan::Extension;
+use base 'DBIx::dbMan::Extension';
 use Text::FormatTable;
 use DBI;
 
-$VERSION = '0.05';
-@ISA = qw/DBIx::dbMan::Extension/;
+our $VERSION = '0.06';
 
 1;
 
-sub IDENTIFICATION { return "000001-000005-000005"; }
+sub IDENTIFICATION { return "000001-000005-000006"; }
 
 sub preference { return 0; }
 
